Structs
- AppState
- Application state for the TUI.
- Pending
Drop - Data retained while the user is shown the drop confirmation dialog.
- Pending
Split - Data retained while the user is shown the large-split confirmation dialog.
Enums
- AppAction
- Result of a view module’s
handle_keyfunction. - AppMode
- Application display mode.
- KeyCommand
- Semantic commands derived from keyboard input.
- Split
Strategy - Split strategy options.
Functions
- read_
event - Read the next terminal event.