Functions
- edit_
message_ in_ editor - Open
messagein the configured editor and return the edited result. - open_
file_ in_ editor - Open an existing working-tree file in the configured editor.
message in the configured editor and return the edited result.