pub enum SquashRelation {
NoRelation,
Squashable,
Conflicting,
}Expand description
The relationship between two commits within a specific cluster.
Used to determine if commits that touch the same cluster can be safely squashed together, following the original fragmap logic.
Variants
NoRelation
Neither commit (or only one) touches this cluster.
Squashable
Both commits touch the cluster with no collisions in between. These commits can potentially be squashed (yellow in UI).
Conflicting
Both commits touch the cluster with collisions (commits in between also touch it). Squashing would conflict (red in UI).