Module mergetool

Module mergetool 

Functions

resolve_merge_tool_cmd
Resolve the shell command to use for the configured merge tool.
run_mergetool
Launch the configured merge tool for every file in conflicting_files.