Module repo

Module repo 

Re-exports

pub use git2_impl::Git2Repo;

Modules

git2_impl

Structs

ConflictState
Enough state to resume or abort a conflicted rebase.
SquashContext
Extra state carried through a squash-time conflict so that the squash can be finalized after the user resolves the conflicting tree.

Enums

RebaseOutcome
Result of a rebase operation that may encounter merge conflicts.

Traits

GitRepo
Abstraction over git repository operations.