Git2Repo

Struct Git2Repo 

pub struct Git2Repo { /* private fields */ }
Concrete git repository backed by libgit2 via the git2 crate.

Construct with Git2Repo::open; then use through the GitRepo trait.

Implementations

Source

impl Git2Repo

pub fn open(path: PathBuf) -> Result<Self>

Try to open a git repository by iteratively trying the given path and its parents until a repository root is found.