Module commit_list

Module commit_list 

Functions

handle_key
Handle an action while in CommitList mode.
render
Render the commit list view.
render_in_area
Render the commit list view in a specific area.
render_in_area_without_fragmap_cols
Render the commit list view in a specific area, without showing fragmap columns. The fragmap is still used for row coloring; only the column display is suppressed. Used by the detail-panel split view where fragmap columns would be out of place.