Constants
Functions
- build_
fragmap_ cell - Build a single fragmap cell from the visible cluster columns.
- commit_
text_ style - Compute the text style for a commit row based on its fragmap relationship to the currently selected commit.
- render_
horizontal_ scrollbar - Render the horizontal scrollbar for the fragmap columns.