commit_text_style

Function commit_text_style 

pub fn commit_text_style(
    fragmap: &FragMap,
    selection_idx: usize,
    commit_idx: usize,
) -> Style
Compute the text style for a commit row based on its fragmap relationship to the currently selected commit.

Yellow: squash partner — either the selected commit can squash into this commit, or this commit can squash into the selected commit. Red: shares a cluster but not a squash partner. DarkGray: this commit is itself fully squashable (intrinsic property).