Functions
- handle_
key - Handle an action while in CommitList mode.
- render
- Render the commit list view.
- render_
in_ area - Render the commit list view in a specific area.
- render_
in_ area_ without_ fragmap_ cols - Render the commit list view in a specific area, without showing fragmap columns. The fragmap is still used for row coloring; only the column display is suppressed. Used by the detail-panel split view where fragmap columns would be out of place.