pub fn render(app: &mut AppState, frame: &mut Frame<'_>)
Render the commit list view.
Takes application state and renders the commit list to the terminal frame. If area is provided, uses that instead of the full frame area.
area