Module hunk_groups

Module hunk_groups 

Constants

COLOR_CONFLICTING
COLOR_SQUASHABLE

Functions

build_fragmap_cell
Build a single fragmap cell from the visible cluster columns.
commit_text_style
Compute the text style for a commit row based on its fragmap relationship to the currently selected commit.
render_horizontal_scrollbar
Render the horizontal scrollbar for the fragmap columns.